==> prestashop_1.4.0.17.zip: prestashop/modules/twenga/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'Twenga API';
$_MODULE['<{twenga}prestashop>twenga_ef538d017142a890fc8b8248813b272e'] = 'Esporta i tuoi prodotti Twenga.com e utilizza il tracker Twenga per l\'ordine del cliente.';
$_MODULE['<{twenga}prestashop>twenga_2034864b8a4fce12f3621b7ec8912e95'] = 'Il modulo Twenga funziona solo in determinati paesi (elenco dei codici ISO:';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Param. non sono ammessi (vedi dettagli):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Si è verificato un errore con il metodo Twenga API (vedi dettagli):';
$_MODULE['<{twenga}prestashop>twenga_7edef656ee9e8861e734336a7adba650'] = 'Il tuo hashkey non è valido. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_3e6f1d35bdb6d0721c83c0a3f48ae345'] = 'Il tuo nome utente non è valido. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_19183e4de8ddfa3e032c112ba45fdc13'] = 'La tua password non è valida. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_802b207b05fe5cea22e11b9db804b33d'] = 'La tua autenticazione non è riuscita.';
$_MODULE['<{twenga}prestashop>twenga_6702ebde453c9145652c0b007489904c'] = 'Controllare la mail  inviata da Twenga dopo l\'iscrizione. Se continua a verificarsi un errore, contatta il servizio di Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Si è verificato un errore durante il passaggio dei param. in Twenga API';
$_MODULE['<{twenga}prestashop>twenga_5d79ec5a879860ff8546580001fe80ee'] = 'Si prega di attivare l\'estensione PHP  \'curl\' per permettere l\'uso della libreria webservice Twenga';
$_MODULE['<{twenga}prestashop>twenga_5f77daeb6fc30c87e051e5b5d11b034c'] = 'Alcuni errori si sono verificati con il Twenga API \"ottenere link di sottoscrizione\":';
$_MODULE['<{twenga}prestashop>twenga_da8ac71ff9563d9a5dd0f8894c8bc0ac'] = 'Referenzia i tuoi prodotti su Twenga: 500 clic offerti da Prestashop!';
$_MODULE['<{twenga}prestashop>twenga_b26917587d98330d93f87808fc9d7267'] = 'Iscriviti';
$_MODULE['<{twenga}prestashop>twenga_1d79f46fad241d4984e47165ca578ee9'] = '(Errore/i: si prega di contattare Twenga)';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Aumenta il tuo traffico - 500 click offerti';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Prezzi Twenga ';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Feed URL';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'HashKey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{twenga}prestashop>twenga_dcc247ef0aa275168664ec484511ccef'] = 'Il tuo catalogo sarà referenziato entro dieci giorni su Twenga.';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{twenga}prestashop>twenga_aacdaeaf96cf431c6364b4dfe314b35c'] = 'Queste informazioni faranno parte del modulo di sottoscrizione Twenga';
$_MODULE['<{twenga}prestashop>twenga_e4448edd2a6725ad3b1b7ca31eac1ff0'] = 'Le seguenti informazioni faranno parte della tua iscrizione \"Twenga ready to sell\". Si prega di verificare la validità dei dati';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'url del sito';
$_MODULE['<{twenga}prestashop>twenga_49c0292b84058df9d4ee623efbd680d4'] = 'Feed Url, l\'elenco dei prodotti in XML.';
$_MODULE['<{twenga}prestashop>twenga_9217c70a13a5a37fdef90ed92d18ca1b'] = 'Il valore viene automaticamente riempito, non cambiarlo.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Paese';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Il paese della società e-commerce. Utilizza il codice ISO_3166-1 Alpha-2 per il formato del paese';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'il nome del sito';
$_MODULE['<{twenga}prestashop>twenga_77587239bf4c54ea493c7033e1dbf636'] = 'Cognome';
$_MODULE['<{twenga}prestashop>twenga_bc910f8bdf70f29374f496f05be0330c'] = 'Nome';
$_MODULE['<{twenga}prestashop>twenga_1e884e3078d9978e216a027ecd57fb34'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Telefono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nome organizzazione';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Informazioni legali';
$_MODULE['<{twenga}prestashop>twenga_fc0d317121f61eeb44ede30a6648b9be'] = 'Informazioni legali sulla società';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Indirizzo';
$_MODULE['<{twenga}prestashop>twenga_8116ea5ccd73f945bb5e260861b0b570'] = 'CAP';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Città';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Disabilita Tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Per disabilitare il tracking, clicca sul pulsante seguente:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Disattiva';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Attiva tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Per attivare il tracking, clicca sul pulsante sottostante:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Attivare';
$_MODULE['<{twenga}prestashop>twenga_09d0c75c525a2cb0bf2310e447ea8a45'] = 'La hashkey deve essere impostata per utilizzare Twenga API.';
$_MODULE['<{twenga}prestashop>twenga_12a4f08255155a828e10c2c513595fe1'] = 'Alcuni parametri mancanti, o il sito non esiste';
$_MODULE['<{twenga}prestashop>twengaobj_2823b98d043387f608f16d5830d63f5f'] = 'Per attivare il plugin Twenga, la costante  \"PARTNER_AUTH_KEY\" deve essere impostata. L\'installazione di default di Prestashop contiene questo valore.';
$_MODULE['<{twenga}prestashop>twengaobj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'oggetto per convalidare i campi deve essere un\'istanza della classe TwengaFields';
$_MODULE['<{twenga}prestashop>twengaobj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La risposta HTTP XML non è analizzabile:';
$_MODULE['<{twenga}prestashop>twengaobj_7edc522b57a063ef075b68fdb791af40'] = 'risposta HTTP vuota';
$_MODULE['<{twenga}prestashop>twengaobj_d00d3f61833c8686be3f0ca7df670e20'] = 'Questa chiamata alla Twenga Web Services non è riuscita e ha rinviato uno stato HTTP di% d. Ciò significa:';
$_MODULE['<{twenga}prestashop>twengaobj_5177c3a8e526ccb227441827d43d9583'] = 'La funzione a cui hai tentato di accedere non esiste';
$_MODULE['<{twenga}prestashop>twengaobj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo obbligatorio è vuoto';
$_MODULE['<{twenga}prestashop>twengaobj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Il tipo di parametro che è stato inviato è diverso dal tipo di parametro previsto';
$_MODULE['<{twenga}prestashop>twengaobj_737b702af5cbf3c4b0e7404592bae85e'] = 'Hash key non valido';
$_MODULE['<{twenga}prestashop>twengaobj_c54550e963195bd4e80b862f40b8d574'] = 'Hash key richiesto';
$_MODULE['<{twenga}prestashop>twengaobj_c4e170c475b0285f284ccb066bcd81f4'] = 'Nessun ordine trovato. Verifica i parametri che hai inviato';
$_MODULE['<{twenga}prestashop>twengaobj_54441256ce04ab07a29463646d0a9931'] = 'È richiesta l\'autenticazione.';
$_MODULE['<{twenga}prestashop>twengaobj_802b207b05fe5cea22e11b9db804b33d'] = 'Autenticazione non riuscita.';
$_MODULE['<{twenga}prestashop>twengaobj_629a8cfa226f98886062bfdc9666e266'] = 'URL non valido.';
$_MODULE['<{twenga}prestashop>twengaobj_9fb66ea632c1aff220b180918df3c77c'] = 'Il server ha rilevato un errore interno del server';
$_MODULE['<{twenga}prestashop>twengaobj_6e182f2ba494a6720ce552ed2a255403'] = 'Il server non è disponibile per il momento';
$_MODULE['<{twenga}prestashop>twengaobj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Questa chiamata a PrestaShop Web Services ha rinviato uno stato HTTP inaspettato:';
$_MODULE['<{twenga}prestashop>twengaobj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Errore n.';

==> prestashop_1.4.1.0.zip: prestashop/modules/twenga/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'Twenga API';
$_MODULE['<{twenga}prestashop>twenga_64ef67f03ba236aef261078101017d57'] = 'ruolo Modulo: esportazione dei vostri prodotti su Twenga ed installazione delle vendite di monitoraggio proposto da Twenga (richiede di registrarsi per Twenga)';
$_MODULE['<{twenga}prestashop>twenga_2034864b8a4fce12f3621b7ec8912e95'] = 'Il modulo Twenga funziona solo in determinati paesi (elenco dei codici ISO:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Disattiva';
$_MODULE['<{twenga}prestashop>twenga_526d688f37a86d3c3f27d0c5016eb71d'] = 'Reset';
$_MODULE['<{twenga}prestashop>twenga_a27dfe771799a09fd55fea73286eb6ab'] = 'Disinstalla';
$_MODULE['<{twenga}prestashop>twenga_f2a6c498fb90ee345d997f888fce3b18'] = 'Elimina';
$_MODULE['<{twenga}prestashop>twenga_bf4510198726bc0736e7705e10fffd8b'] = 'Se sei abbonato a Twenga, l\'attivazione di questo modulo è obbligatoria.';
$_MODULE['<{twenga}prestashop>twenga_9d156e107098a77332f309c765b72b9c'] = 'In caso di disfunzione, disinstallare questo modulo, installare la nuova versione qui e riempire di nuovo hashkey Twenga ed effettuare il login.';
$_MODULE['<{twenga}prestashop>twenga_a9d7299384e1f3fc346790328ffa8ac3'] = 'Per annullare l\'iscrizione o per qualsiasi domanda, si prega di contattare Twenga sul tuo conto.';
$_MODULE['<{twenga}prestashop>twenga_fb3ecfb2800400fb01b0bfd39903e9fb'] = 'Nuova versione';
$_MODULE['<{twenga}prestashop>twenga_ea4788705e6873b424c65e91c2846b19'] = 'Annulla';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Param. non sono ammessi (vedi dettagli):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Si è verificato un errore con il metodo Twenga API (vedi dettagli):';
$_MODULE['<{twenga}prestashop>twenga_7edef656ee9e8861e734336a7adba650'] = 'Il tuo hashkey non è valido. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_3e6f1d35bdb6d0721c83c0a3f48ae345'] = 'Il tuo nome utente non è valido. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_19183e4de8ddfa3e032c112ba45fdc13'] = 'La tua password non è valida. Si prega di controllare la mail già inviata da Twenga.';
$_MODULE['<{twenga}prestashop>twenga_802b207b05fe5cea22e11b9db804b33d'] = 'La tua autenticazione non è riuscita.';
$_MODULE['<{twenga}prestashop>twenga_6702ebde453c9145652c0b007489904c'] = 'Controllare la mail  inviata da Twenga dopo l\'iscrizione. Se continua a verificarsi un errore, contatta il servizio di Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Si è verificato un errore durante il passaggio dei param. in Twenga API';
$_MODULE['<{twenga}prestashop>twenga_94a3b708cddc22d83742fdbd0a8970d7'] = 'Il vostro Paese di default è';
$_MODULE['<{twenga}prestashop>twenga_1f75825a8f4b083cbed0f95efc09abfd'] = 'Si prega di selezionare uno di questi paesi a disposizione approvata dal Twenga';
$_MODULE['<{twenga}prestashop>twenga_3ea33020a5535b0157de47e53e463633'] = 'Segui questo link per cambiare il Paese';
$_MODULE['<{twenga}prestashop>twenga_5d79ec5a879860ff8546580001fe80ee'] = 'Si prega di attivare l\'estensione PHP  \'curl\' per permettere l\'uso della libreria webservice Twenga';
$_MODULE['<{twenga}prestashop>twenga_5f77daeb6fc30c87e051e5b5d11b034c'] = 'Alcuni errori si sono verificati con il Twenga API \"ottenere link di sottoscrizione\":';
$_MODULE['<{twenga}prestashop>twenga_da8ac71ff9563d9a5dd0f8894c8bc0ac'] = 'Indicizza i tuoi prodotti su Twenga';
$_MODULE['<{twenga}prestashop>twenga_0ed6e223384a822859461ca6bab72256'] = 'Sei già inscritto a Twenga Ready to Sell ? ';
$_MODULE['<{twenga}prestashop>twenga_63f97ef2cb80a6cf0a8fa98453577601'] = 'Step 1 : Recupera la hashkey Twenga dal tuo conto Twenga Ready to Sell (tools>tracking>hashkey). Clicca su \"Testare il tracking\". ';
$_MODULE['<{twenga}prestashop>twenga_5ac315e486b693637a06f490f308dc67'] = 'Step 2 : Ritorna su questa pagina copia la hashkey nel campo „hash key“. Clicca su  Save e Activate.';
$_MODULE['<{twenga}prestashop>twenga_f5cff2635ec9ecf0249d33a7656f61c5'] = 'Vuoi iscriverti a Twenga Ready to Sell ? ';
$_MODULE['<{twenga}prestashop>twenga_f9c31cabc1e6928068e7394f5453e759'] = 'Come indicizzare i tuoi prodotti su Twenga.it';
$_MODULE['<{twenga}prestashop>twenga_87645feb1c92efecd6a6946d1b498fd7'] = 'Step 1 : Per iscriverti a Twenga Ready to Sell clicca su questo link';
$_MODULE['<{twenga}prestashop>twenga_b26917587d98330d93f87808fc9d7267'] = 'Iscriviti';
$_MODULE['<{twenga}prestashop>twenga_1d79f46fad241d4984e47165ca578ee9'] = '(Errore/i: si prega di contattare Twenga)';
$_MODULE['<{twenga}prestashop>twenga_195b3777fa9dcc91d27b86391e7f9a49'] = 'Step 2 : Compila i campi richiesti per l’iscrizione  ';
$_MODULE['<{twenga}prestashop>twenga_767a31e960aa760c42722d2e7373b2ad'] = 'Step 3 : Una volta ricevuta la hashkey Twenga via email, ritorna su questa pagina e copiala nel campo „hash key“. Clicca su Salva e poi su Attivare';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Aumenta il tuo traffico - 500 click offerti';
$_MODULE['<{twenga}prestashop>twenga_2d82e5a3931e70d2c94b9ba6e674edbc'] = 'Clicca qui per visonare i costi per categoria Twenga';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Prezzi Twenga ';
$_MODULE['<{twenga}prestashop>twenga_1b972277504e523b2354830a1cbbf34b'] = 'Installazione di Sales Tracking';
$_MODULE['<{twenga}prestashop>twenga_1b8d7e57253e5bdb39a7f8a8e4604a87'] = 'Inserisci qui il tuo Ready Twenga per vendere e hashkey login e password';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Feed URL';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'HashKey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Password';
$_MODULE['<{twenga}prestashop>twenga_dcc247ef0aa275168664ec484511ccef'] = 'Il tuo catalogo sarà referenziato entro dieci giorni su Twenga.';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{twenga}prestashop>twenga_aacdaeaf96cf431c6364b4dfe314b35c'] = 'Queste informazioni faranno parte del modulo di sottoscrizione Twenga';
$_MODULE['<{twenga}prestashop>twenga_e4448edd2a6725ad3b1b7ca31eac1ff0'] = 'Le seguenti informazioni faranno parte della tua iscrizione \"Twenga ready to sell\". Si prega di verificare la validità dei dati';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'url del sito';
$_MODULE['<{twenga}prestashop>twenga_49c0292b84058df9d4ee623efbd680d4'] = 'Feed Url, l\'elenco dei prodotti in XML.';
$_MODULE['<{twenga}prestashop>twenga_9217c70a13a5a37fdef90ed92d18ca1b'] = 'Il valore viene automaticamente riempito, non cambiarlo.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Paese';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Il paese della società e-commerce. Utilizza il codice ISO_3166-1 Alpha-2 per il formato del paese';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'il nome del sito';
$_MODULE['<{twenga}prestashop>twenga_77587239bf4c54ea493c7033e1dbf636'] = 'Cognome';
$_MODULE['<{twenga}prestashop>twenga_bc910f8bdf70f29374f496f05be0330c'] = 'Nome';
$_MODULE['<{twenga}prestashop>twenga_1e884e3078d9978e216a027ecd57fb34'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Telefono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nome organizzazione';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Informazioni legali';
$_MODULE['<{twenga}prestashop>twenga_fc0d317121f61eeb44ede30a6648b9be'] = 'Informazioni legali sulla società';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Indirizzo';
$_MODULE['<{twenga}prestashop>twenga_8116ea5ccd73f945bb5e260861b0b570'] = 'CAP';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Città';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Disabilita Tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Per disabilitare il tracking, clicca sul pulsante seguente:';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Attiva tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Per attivare il tracking, clicca sul pulsante sottostante:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Attivare';
$_MODULE['<{twenga}prestashop>twenga_09d0c75c525a2cb0bf2310e447ea8a45'] = 'La hashkey deve essere impostata per utilizzare Twenga API.';
$_MODULE['<{twenga}prestashop>twenga_12a4f08255155a828e10c2c513595fe1'] = 'Alcuni parametri mancanti, o il sito non esiste';
$_MODULE['<{twenga}prestashop>twengaobj_2823b98d043387f608f16d5830d63f5f'] = 'Per attivare il plugin Twenga, la costante  \"PARTNER_AUTH_KEY\" deve essere impostata. L\'installazione di default di Prestashop contiene questo valore.';
$_MODULE['<{twenga}prestashop>twengaobj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'oggetto per convalidare i campi deve essere un\'istanza della classe TwengaFields';
$_MODULE['<{twenga}prestashop>twengaobj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La risposta HTTP XML non è analizzabile:';
$_MODULE['<{twenga}prestashop>twengaobj_7edc522b57a063ef075b68fdb791af40'] = 'risposta HTTP vuota';
$_MODULE['<{twenga}prestashop>twengaobj_d00d3f61833c8686be3f0ca7df670e20'] = 'Questa chiamata alla Twenga Web Services non è riuscita e ha rinviato uno stato HTTP di% d. Ciò significa:';
$_MODULE['<{twenga}prestashop>twengaobj_5177c3a8e526ccb227441827d43d9583'] = 'La funzione a cui hai tentato di accedere non esiste';
$_MODULE['<{twenga}prestashop>twengaobj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo obbligatorio è vuoto';
$_MODULE['<{twenga}prestashop>twengaobj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Il tipo di parametro che è stato inviato è diverso dal tipo di parametro previsto';
$_MODULE['<{twenga}prestashop>twengaobj_737b702af5cbf3c4b0e7404592bae85e'] = 'Hash key non valido';
$_MODULE['<{twenga}prestashop>twengaobj_c54550e963195bd4e80b862f40b8d574'] = 'Hash key richiesto';
$_MODULE['<{twenga}prestashop>twengaobj_c4e170c475b0285f284ccb066bcd81f4'] = 'Nessun ordine trovato. Verifica i parametri che hai inviato';
$_MODULE['<{twenga}prestashop>twengaobj_54441256ce04ab07a29463646d0a9931'] = 'È richiesta l\'autenticazione.';
$_MODULE['<{twenga}prestashop>twengaobj_802b207b05fe5cea22e11b9db804b33d'] = 'Autenticazione non riuscita.';
$_MODULE['<{twenga}prestashop>twengaobj_629a8cfa226f98886062bfdc9666e266'] = 'URL non valido.';
$_MODULE['<{twenga}prestashop>twengaobj_9fb66ea632c1aff220b180918df3c77c'] = 'Il server ha rilevato un errore interno del server';
$_MODULE['<{twenga}prestashop>twengaobj_6e182f2ba494a6720ce552ed2a255403'] = 'Il server non è disponibile per il momento';
$_MODULE['<{twenga}prestashop>twengaobj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Questa chiamata a PrestaShop Web Services ha rinviato uno stato HTTP inaspettato:';
$_MODULE['<{twenga}prestashop>twengaobj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Errore n.';
